@@ -2,23 +2,16 @@ from django.contrib import auth
 from django.dispatch import Signal
 from django.contrib.sites.models import Site
 
-from urlauth.signals import key_loaded, key_processed
+from urlauth.signals import key_user_found
+from urlauth.models import AuthKey
 
 from account.util import email_template
 
-
 account_created = Signal(providing_args=['user'])
 
-
-def login_user(request, user):
-    user.backend = 'django.contrib.auth.backends.ModelBackend'
-    auth.login(request, user)
-
-
-def key_loaded_handler(key, request):
-    extra = key.export_data()
-    action = extr.get('action')
-    user = request.user
+def key_user_found_handler(key, user, **kwargs):
+    extra = key.extra
+    action = extra.get('action')
 
     if 'activation' == action:
         if not user.is_active:
@@ -32,3 +25,6 @@ def key_loaded_handler(key, request):
             if 'email' in extra:
                 user.email = args['email']
                 user.save()
+
+
+key_user_found.connect(key_user_found_handler, sender=AuthKey)
