@@ -15,6 +15,7 @@ from django.shortcuts import render_to_response
 from django.core.mail import send_mail
 from django.conf import settings
 from django.contrib.sites.models import Site
+from django.template import TemplateDoesNotExist
 
 from django.core.mail import EmailMultiAlternatives
 
@@ -64,11 +65,19 @@ def email_template(rcpt, template_path, **kwargs):
     from_email = settings.DEFAULT_FROM_EMAIL
 
     subject = parse_template('%s_subject.txt' % template_path, **kwargs)
-    text_content = parse_template('%s_body.txt' % template_path, mode='text', **kwargs)
-    html_content = parse_template('%s_body.txt' % template_path, mode='html', **kwargs)
+    text_content = parse_template('%s_body.txt' % template_path, **kwargs)
+
+    try:
+        html_content = parse_template('%s_body.html' % template_path, **kwargs)
+    except TemplateDoesNotExist:
+        html_content = None
+
+    # TODO remove after debugging
+    print text_content
 
     msg = EmailMultiAlternatives(subject, text_content, from_email, [rcpt])
-    msg.attach_alternative(html_content, "text/html")
+    if html_content:
+        msg.attach_alternative(html_content, "text/html")
 
     return bool(msg.send(fail_silently=True))
 
